<?php



require_once 'Classes/Astro/MJD.php';
require_once GREEN_ZONE_DIR . 'Utils/MysqlDB.php';



/**
 * This class represents the algorithm for performing a calibration query
 * Usage:
 * $searcher = new CalQuery();
 * $searcher->SetStartTime( $start_mjd );
 * $searcher->SetEndTiem( $end_mjd );
 * $searcher->Execute();
 * $calibrations = $searcher->GetCalibrations();
 **/

class CalQuery
{
  // PUBLIC
  
  public function __construct()
  {
    $this->start_mjd = new MJD();
    $this->end_mjd = new MJD();
    $this->results = Array();
    $this->database = null;
  }
  
  public function SetStartTime( MJD $s_start_time ) { $this->start_time = $s_start_time; }
  public function SetEndTime( MJD $s_end_time ) { $this->end_time = $s_end_time; }
  
  public function Execute()
  {
    $select_sql = ' SELECT * FROM cals WHERE MJD < ' . $this->end_time->ToString();
    $select_sql .= ' AND MJD > ' . $this->start_time->ToString();
    
                  //echo 'executing cal query ' . $select_sql . ' <br> ';
                  
    $this->database->DoQuery( $select_sql );
    
    if( $this->database->FetchNumRows() > 0 )
      $this->ExtractResults( $this->database->GetLastResult() );
  }
  
  public function GetCalibrations() { return $this->results; }
  
  public function SetDatabase( MysqlDB $s_database ) { $this->database = $s_database; }
  
  // PRIVATE
  
  private $start_mjd;
  private $end_mjd;
  private $results;
  private $database;
  
  private function ExtractResults( $array_data )
  {
    foreach( $array_data as $next_record )
    {
      $new_calibration = new Calibration();
      $new_calibration->FromRecord( $next_record );
      $this->results[] = $new_calibration;
    }
  }
};





?>