<?php



require_once 'config.php';
require_once 'Classes/General/Pair.php';
require_once GREEN_ZONE_DIR . 'Forms/GZ_BaseForm.php';
require_once GREEN_ZONE_DIR . 'Utils/GZ_DataMapper.php';



class GZ_Table extends GZ_BaseForm
{
  // PUBLIC

  //! Constructor
  public function __construct( $s_gz, $s_html_id )
  {
    parent::__construct( $s_gz );
    
    $this->data_set = Array();
    $this->headings = Array();
    $this->show_range = new Pair();
    $this->show_columns = Array();
    $this->selected_ids = Array();
    $this->data_mapper = null;
    $this->html_id = $s_html_id;
    $this->html_selections_id = $s_html_id . 'Selections';
  }
  
  //! Return the ids for the rows that the user has selected.
  public function GetSelectedIDs() { return $this->selected_ids; }
  
  //! Set the ids to show as selected
  public function SetSelectedIDs( $s_selected_ids ) { $this->selected_ids = $s_selected_ids; }
  
  //! Set all the entries as selected
  public function SelectAll()
  {
    if( $this->data_mapper == null )
      throw new GZ_Exception( 'No mapper set for table', 'GZ_Table::SelectAll' );

    $this->selected_ids = Array();
    foreach( $this->data_set as $next_item )
    {
      $this->data_mapper->SetInstance( $next_item );
      $this->selected_ids[] = $this->data_mapper->GetValue( 'primary_key' );
    }
  }
  
  //! Set the column headings
  public function SetColumnHeadings( $s_headings ) { $this->headings = $s_headings; }
  
  //! Get the column headings
  public function GetColumnHeadings() { return $this->headings; }
  
  //! Set the range of items to show
  public function SetRange( Pair $s_range ) { $this->show_range = $s_range; }
  
  //! Set the data set to display
  public function SetData( $s_data_set ) { $this->data_set = $s_data_set; }
  
  //! Get the number of items in the data set
  public function GetNumItems() { return count( $this->data_set ); }
  
  //! Set the mapper to use to get fields from the data, must contain a primary_key mapping
  public function SetDataMapper( $s_data_mapper ) { $this->data_mapper = $s_data_mapper; }
  
  /**
   * Render the html for this table to output.
   **/
  public function Display()
  {
    // If our range is outside the data set, move it to something more sensible
	
    if( $this->show_range->first > count( $this->data_set ) - 1)
      $this->show_range->first = 0;
    if( $this->show_range->second > count( $this->data_set ) - 1 )
      $this->show_range->second = count( $this->data_set ) - 1;

    // grab just the rows that are in range
    
    $display_data = $this->DataToArray();
    
    // Setup some class variables
    // TODO make these settable by members
    
    $td_class = 'result_row';
    $tr_class = 'QueryResultsTR';
    $thr_class = 'QueryResultsHeaderTR';


    $smarty = $this->gz->CreateSmarty();

    $this->gz->smarty_assign( $smarty, 'selected_ids', $this->selected_ids );
    $this->gz->smarty_assign( $smarty, 'data_set', $display_data );
    $this->gz->smarty_assign( $smarty, 'headings', $this->headings );
    $this->gz->smarty_assign( $smarty, 'td_class', $td_class );
    $this->gz->smarty_assign( $smarty, 'tr_class', $tr_class );
    $this->gz->smarty_assign( $smarty, 'thr_class', $thr_class );
    $this->gz->smarty_assign( $smarty, 'html_id', $this->html_id );
    $this->gz->smarty_assign( $smarty, 'html_selections_id', $this->html_selections_id );

    $smarty->display( 'GZ_Table.tpl' );
  }
  
  public function ReadForm()
  {
    // read the array of selected ids from the post data

    $this->selected_ids = Array();
    if( isset( $this->gz->_POST[$this->html_selections_id] ) )
      $this->selected_ids = $this->gz->_POST[$this->html_selections_id];
  }
  
  public function ProcessActions()
  {
    if( $this->ActionIs( $this->html_id . 'SelectAll' ) )
      $this->SelectAll();

    return '';
  }
  
  // PRIVATE

  private $data_set;
  private $data_mapper;
  private $show_range;
  private $order_column_name;
  private $order_column_direction;
  private $show_columns;
  private $html_id;
  private $html_selections_id;
  private $selected_ids;
  

  //! This function returns an array with the data ready for display
  public function DataToArray()
  {
    $converted_rows = Array();
    
    for( $ind = $this->show_range->first; $ind <= $this->show_range->second; $ind ++ )
    {
      $next_observation = $this->data_set[$ind];
      
      $this->data_mapper->SetInstance( $next_observation );

      $new_row = Array();
      $new_row['id'] = $this->data_mapper->GetValue('primary_key');
      $new_cell = Array();
      $new_row['cells'] = Array();
      foreach( $this->GetColumnHeadings() as $next_col_name )
      {
        $next_value = $this->data_mapper->GetValue( $next_col_name );

	$new_cell['value'] = $next_value;
	
	$new_cell['children'] = Array();
	$children = $next_observation->GetChildren();
	$child_interface = $next_observation->GetChildInterface();
	foreach( $children as $next_child )
	{
	  $child_interface->SetInstance( $next_child );
	  $new_cell['children'][] = $child_interface->GetValue( $next_col_name  );
	}
	
	$new_row['cells'][] = $new_cell;
      }

      $converted_rows[] = $new_row;
    }
    
    return $converted_rows;
  }
};

?>